@@ -12,7 +12,7 @@ BIFIE.logistreg <- function( BIFIEobj , dep=NULL , pre=NULL  ,
 	if (bifieobj$cdata){	
 	    formula_vars <- NULL		
 		if (! is.null(formula) ){
-			formula_vars <- all.vars( formula )
+			formula_vars <- base::all.vars( formula )
 							}
 		varnames <- unique( c( dep , pre , group , "one" , formula_vars ) )
 		bifieobj <- BIFIE.BIFIEcdata2BIFIEdata( bifieobj , varnames=varnames )	
@@ -30,19 +30,19 @@ BIFIE.logistreg <- function( BIFIEobj , dep=NULL , pre=NULL  ,
 
 	#*** look for formula objects
 	if ( ! is.null( formula) ){
-	    cat("|*** Data Preparation ") ; flush.console()
+	    cat("|*** Data Preparation ") ; utils::flush.console()
 	    bifieobj2 <- datalistM
 		colnames(bifieobj2) <- varnames
 		if ( is.null(group) ){ group <- "one" ; group_values <- 1 }
 		bifieobj2 <- as.data.frame( bifieobj2 )
-	    m1 <- model.matrix(formula , data=bifieobj2)
+	    m1 <- stats::model.matrix(formula , data=bifieobj2)
 		#***
         m0 <- m1
 		m1 <- matrix( NA , nrow=nrow(bifieobj2) , ncol=ncol(m0) )
 		m1[ match( rownames(m0),rownames(bifieobj2) ) , ] <- m0
 		colnames(m1) <- colnames(m0)
 		#****
-		dep <- rownames( attr( terms(formula) ,"factors") )[1]
+		dep <- rownames( attr( stats::terms(formula) ,"factors") )[1]
 		pre <- colnames( m1 )
 		datalistM <- as.matrix( cbind( bifieobj2[ , dep  ] , m1 , bifieobj2[,group] ) )
 		varnames <- c( dep , pre , group )	
